EXPORTS
	??0CTFAActiveTest@@QAE@AAVMTFAActiveTest@@@Z @ 1 NONAME ; public: __thiscall CTFAActiveTest::CTFAActiveTest(class MTFAActiveTest &)
	??0CTFAEntryPoint@@IAE@XZ @ 2 NONAME ; protected: __thiscall CTFAEntryPoint::CTFAEntryPoint(void)
	??0CTFATestCase@@IAE@HABVTDesC16@@@Z @ 3 NONAME ; protected: __thiscall CTFATestCase::CTFATestCase(int,class TDesC16 const &)
	??0CTFATestCaseAdapter@@IAE@AAVCTFATestCase@@@Z @ 4 NONAME ; protected: __thiscall CTFATestCaseAdapter::CTFATestCaseAdapter(class CTFATestCase &)
	??0CTFATestEnvironment@@QAE@AAVCTFATestLog@@@Z @ 5 NONAME ; public: __thiscall CTFATestEnvironment::CTFATestEnvironment(class CTFATestLog &)
	??0CTFATestLog@@IAE@XZ @ 6 NONAME ; protected: __thiscall CTFATestLog::CTFATestLog(void)
	??0CTFATestSuite@@QAE@ABVTDesC16@@@Z @ 7 NONAME ; public: __thiscall CTFATestSuite::CTFATestSuite(class TDesC16 const &)
	??0CTFATestSuiteAdapter@@IAE@AAVCTFATestSuite@@PAVCTFAEntryPoint@@@Z @ 8 NONAME ; protected: __thiscall CTFATestSuiteAdapter::CTFATestSuiteAdapter(class CTFATestSuite &,class CTFAEntryPoint *)
	??0CTFRemoteStub@@QAE@H@Z @ 9 NONAME ; public: __thiscall CTFRemoteStub::CTFRemoteStub(int)
	??0CTFStub@@QAE@H@Z @ 10 NONAME ; public: __thiscall CTFStub::CTFStub(int)
	??0CTFStubTestCase@@QAE@H@Z @ 11 NONAME ; public: __thiscall CTFStubTestCase::CTFStubTestCase(int)
	??0CTFStubTestCaseParam@@QAE@XZ @ 12 NONAME ; public: __thiscall CTFStubTestCaseParam::CTFStubTestCaseParam(void)
	??0CTFTestCaseRepeater@@QAE@HABVTDesC16@@PAVCTFATestSuite@@HH@Z @ 13 NONAME ; public: __thiscall CTFTestCaseRepeater::CTFTestCaseRepeater(int,class TDesC16 const &,class CTFATestSuite *,int,int)
	??0CTFTestCaseWrapper@@QAE@HABVTDesC16@@@Z @ 14 NONAME ; public: __thiscall CTFTestCaseWrapper::CTFTestCaseWrapper(int,class TDesC16 const &)
	??0MTFAActiveTest@@QAE@XZ @ 15 NONAME ; public: __thiscall MTFAActiveTest::MTFAActiveTest(void)
	??0MTFATestAdapter@@IAE@XZ @ 16 NONAME ; protected: __thiscall MTFATestAdapter::MTFATestAdapter(void)
	??0MTFATestCaseAdapter@@IAE@XZ @ 17 NONAME ; protected: __thiscall MTFATestCaseAdapter::MTFATestCaseAdapter(void)
	??0MTFATestSuiteAdapter@@IAE@XZ @ 18 NONAME ; protected: __thiscall MTFATestSuiteAdapter::MTFATestSuiteAdapter(void)
	??1CTFAActiveTest@@UAE@XZ @ 19 NONAME ; public: virtual __thiscall CTFAActiveTest::~CTFAActiveTest(void)
	??1CTFAEntryPoint@@UAE@XZ @ 20 NONAME ; public: virtual __thiscall CTFAEntryPoint::~CTFAEntryPoint(void)
	??1CTFATestCase@@MAE@XZ @ 21 NONAME ; protected: virtual __thiscall CTFATestCase::~CTFATestCase(void)
	??1CTFATestCaseAdapter@@UAE@XZ @ 22 NONAME ; public: virtual __thiscall CTFATestCaseAdapter::~CTFATestCaseAdapter(void)
	??1CTFATestEnvironment@@UAE@XZ @ 23 NONAME ; public: virtual __thiscall CTFATestEnvironment::~CTFATestEnvironment(void)
	??1CTFATestLog@@UAE@XZ @ 24 NONAME ; public: virtual __thiscall CTFATestLog::~CTFATestLog(void)
	??1CTFATestSuite@@UAE@XZ @ 25 NONAME ; public: virtual __thiscall CTFATestSuite::~CTFATestSuite(void)
	??1CTFATestSuiteAdapter@@UAE@XZ @ 26 NONAME ; public: virtual __thiscall CTFATestSuiteAdapter::~CTFATestSuiteAdapter(void)
	??1CTFATestTimer@@UAE@XZ @ 27 NONAME ; public: virtual __thiscall CTFATestTimer::~CTFATestTimer(void)
	??1CTFRemoteStub@@UAE@XZ @ 28 NONAME ; public: virtual __thiscall CTFRemoteStub::~CTFRemoteStub(void)
	??1CTFStub@@UAE@XZ @ 29 NONAME ; public: virtual __thiscall CTFStub::~CTFStub(void)
	??1CTFStubTestCase@@UAE@XZ @ 30 NONAME ; public: virtual __thiscall CTFStubTestCase::~CTFStubTestCase(void)
	??1CTFStubTestCaseParam@@UAE@XZ @ 31 NONAME ; public: virtual __thiscall CTFStubTestCaseParam::~CTFStubTestCaseParam(void)
	??1MTFAActiveTest@@UAE@XZ @ 32 NONAME ; public: virtual __thiscall MTFAActiveTest::~MTFAActiveTest(void)
	??1MTFATestAdapter@@UAE@XZ @ 33 NONAME ; public: virtual __thiscall MTFATestAdapter::~MTFATestAdapter(void)
	??1MTFATestCaseAdapter@@UAE@XZ @ 34 NONAME ; public: virtual __thiscall MTFATestCaseAdapter::~MTFATestCaseAdapter(void)
	??1MTFATestSuiteAdapter@@UAE@XZ @ 35 NONAME ; public: virtual __thiscall MTFATestSuiteAdapter::~MTFATestSuiteAdapter(void)
	?AddL@CTFATestSuite@@QAEXABVCTFATest@@@Z @ 36 NONAME ; public: void __thiscall CTFATestSuite::AddL(class CTFATest const &)
	?AddL@CTFATestSuiteAdapter@@UAEXAAVMTFATestAdapter@@@Z @ 37 NONAME ; public: virtual void __thiscall CTFATestSuiteAdapter::AddL(class MTFATestAdapter &)
	?AddStubTestCaseL@CTFTestCaseWrapper@@QAEXAAVMTFStubTestCase@@@Z @ 38 NONAME ; public: void __thiscall CTFTestCaseWrapper::AddStubTestCaseL(class MTFStubTestCase &)
	?At@CTFATestSuite@@QAEAAVCTFATest@@H@Z @ 39 NONAME ; public: class CTFATest & __thiscall CTFATestSuite::At(int)
	?CallLocalStubL@CTFFactory@@SAXHPAX000@Z @ 40 NONAME ; public: static void __cdecl CTFFactory::CallLocalStubL(int,void *,void *,void *,void *)
	?CallRemoteStubL@CTFFactory@@SAXHPAX000@Z @ 41 NONAME ; public: static void __cdecl CTFFactory::CallRemoteStubL(int,void *,void *,void *,void *)
	?CallRemoteStubL@CTFFactory@@SAXHPAX000AAVTRequestStatus@@@Z @ 42 NONAME ; public: static void __cdecl CTFFactory::CallRemoteStubL(int,void *,void *,void *,void *,class TRequestStatus &)
	?CompleteTest@CTFStubTestCase@@MAEXH@Z @ 43 NONAME ; protected: virtual void __thiscall CTFStubTestCase::CompleteTest(int)
	?ConstructL@CTFAEntryPoint@@MAEXXZ @ 44 NONAME ; protected: virtual void __thiscall CTFAEntryPoint::ConstructL(void)
	?Count@CTFATestSuite@@QBEHXZ @ 45 NONAME ; public: int __thiscall CTFATestSuite::Count(void)const 
	?CurrentTestCase@CTFStub@@QAEPAVMTFStubTestCase@@XZ @ 46 NONAME ; public: class MTFStubTestCase * __thiscall CTFStub::CurrentTestCase(void)
	?CurrentTestCaseID@CTFStub@@QAEHXZ @ 47 NONAME ; public: int __thiscall CTFStub::CurrentTestCaseID(void)
	?DoSetActive@CTFAActiveTest@@QAEXXZ @ 48 NONAME ; public: void __thiscall CTFAActiveTest::DoSetActive(void)
	?Environment@CTFATest@@QAEAAVCTFATestEnvironment@@XZ @ 49 NONAME ; public: class CTFATestEnvironment & __thiscall CTFATest::Environment(void)
	?Factory@CTFATestEnvironment@@QAEPAVCTFFactory@@XZ @ 50 NONAME ; public: class CTFFactory * __thiscall CTFATestEnvironment::Factory(void)
	?Id@CTFATestCase@@QBEHXZ @ 51 NONAME ; public: int __thiscall CTFATestCase::Id(void)const 
	?IsComplete@CTFStubTestCase@@UAEHXZ @ 52 NONAME ; public: virtual int __thiscall CTFStubTestCase::IsComplete(void)
	?Logger@CTFATestEnvironment@@QAEAAVCTFATestLog@@XZ @ 53 NONAME ; public: class CTFATestLog & __thiscall CTFATestEnvironment::Logger(void)
	?Logger@CTFStubTestCase@@MAEAAVCTFATestLog@@XZ @ 54 NONAME ; protected: virtual class CTFATestLog & __thiscall CTFStubTestCase::Logger(void)
	?Name@CTFATest@@QBEABVTDesC16@@XZ @ 55 NONAME ; public: class TDesC16 const & __thiscall CTFATest::Name(void)const 
	?NewL@CTFATestTimer@@SAPAV1@AAVMTFAActiveTest@@@Z @ 56 NONAME ; public: static class CTFATestTimer * __cdecl CTFATestTimer::NewL(class MTFAActiveTest &)
	?RootSuiteAdapter@CTFAEntryPoint@@QAEPAVMTFATestSuiteAdapter@@XZ @ 57 NONAME ; public: class MTFATestSuiteAdapter * __thiscall CTFAEntryPoint::RootSuiteAdapter(void)
	?RunOnStartup@CTFATestCase@@QBEHXZ @ 58 NONAME ; public: int __thiscall CTFATestCase::RunOnStartup(void)const 
	?SetCallback@CTFStubTestCase@@UAEXAAVMTFTestCaseInterface@@@Z @ 59 NONAME ; public: virtual void __thiscall CTFStubTestCase::SetCallback(class MTFTestCaseInterface &)
	?SetEnvironment@CTFATest@@UAEXAAVCTFATestEnvironment@@@Z @ 60 NONAME ; public: virtual void __thiscall CTFATest::SetEnvironment(class CTFATestEnvironment &)
	?SetEnvironment@CTFTestCaseRepeater@@UAEXAAVCTFATestEnvironment@@@Z @ 61 NONAME ; public: virtual void __thiscall CTFTestCaseRepeater::SetEnvironment(class CTFATestEnvironment &)
	?SetEnvironment@CTFTestCaseWrapper@@UAEXAAVCTFATestEnvironment@@@Z @ 62 NONAME ; public: virtual void __thiscall CTFTestCaseWrapper::SetEnvironment(class CTFATestEnvironment &)
	?SetRunOnStartup@CTFATestCase@@QAEXH@Z @ 63 NONAME ; public: void __thiscall CTFATestCase::SetRunOnStartup(int)
	?SetStub@CTFStubTestCase@@UAEXAAVCTFStub@@@Z @ 64 NONAME ; public: virtual void __thiscall CTFStubTestCase::SetStub(class CTFStub &)
	?SetTimeout@CTFATestCase@@QAEXH@Z @ 65 NONAME ; public: void __thiscall CTFATestCase::SetTimeout(int)
	?SetupL@CTFStubTestCase@@UAEXXZ @ 66 NONAME ; public: virtual void __thiscall CTFStubTestCase::SetupL(void)
	?Status@CTFAActiveTest@@QAEAAVTRequestStatus@@XZ @ 67 NONAME ; public: class TRequestStatus & __thiscall CTFAActiveTest::Status(void)
	?Stub@CTFFactory@@SAPAVCTFStub@@H@Z @ 68 NONAME ; public: static class CTFStub * __cdecl CTFFactory::Stub(int)
	?StubControl@CTFFactory@@QAEPAVMTFStubControl@@XZ @ 69 NONAME ; public: class MTFStubControl * __thiscall CTFFactory::StubControl(void)
	?Timeout@CTFATestCase@@QBEHXZ @ 70 NONAME ; public: int __thiscall CTFATestCase::Timeout(void)const 
	?Type@CTFATestCase@@UBE?AW4TTFATestType@@XZ @ 71 NONAME ; public: virtual enum TTFATestType  __thiscall CTFATestCase::Type(void)const 
	?Type@CTFATestCaseAdapter@@UBE?AW4TTFATestType@@XZ @ 72 NONAME ; public: virtual enum TTFATestType  __thiscall CTFATestCaseAdapter::Type(void)const 
	?Type@CTFATestSuite@@UBE?AW4TTFATestType@@XZ @ 73 NONAME ; public: virtual enum TTFATestType  __thiscall CTFATestSuite::Type(void)const 
	?Type@CTFATestSuiteAdapter@@UBE?AW4TTFATestType@@XZ @ 74 NONAME ; public: virtual enum TTFATestType  __thiscall CTFATestSuiteAdapter::Type(void)const 
	?Type@CTFStubTestCase@@UAEHXZ @ 75 NONAME ; public: virtual int __thiscall CTFStubTestCase::Type(void)
	?Flags@CTFATestCase@@QBEKXZ @ 76 NONAME ; public: unsigned long __thiscall CTFATestCase::Flags(void)const 
	?SetFlags@CTFATestCase@@QAEXK@Z @ 77 NONAME ; public: void __thiscall CTFATestCase::SetFlags(unsigned long)
	?SetEnvironment@CTFATestCase@@UAEXAAVCTFATestEnvironment@@@Z @ 78 NONAME ; public: virtual void __thiscall CTFATestCase::SetEnvironment(class CTFATestEnvironment &)
	?SetTestCaseFlags@CTFATestEnvironment@@QAEXK@Z @ 79 NONAME ; public: void __thiscall CTFATestEnvironment::SetTestCaseFlags(unsigned long)

